@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pdf-meta-edit" "0.2.2"
+(define-package "pdf-meta-edit" "20251118.2327"
   "Edit PDF metadata via pdftk."
   '((emacs  "24.3")
     (compat "29.1"))
